#
# spec file for package ksanecore
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _so 1
%define lname libKSaneCore
%bcond_without released
Name:           ksanecore
Version:        23.08.5
Release:        bp156.2.3.1
Summary:        Qt interface for the SANE library for scanner hardware
License:        LGPL-2.1-only OR LGPL-3.0-only
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
# PATCH-FIX-UPSTREAM
Patch0:         fix-scanner-search-crash.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  sane-backends-devel
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Test)

%description
KSaneCore is a Qt-based interface for SANE library to control scanner hardware.

%package devel
Summary:        Development files for KSaneCore, a Qt library for scanner hardware
Requires:       %{lname}%{_so} = %{version}
Requires:       pkgconfig
Requires:       sane-backends-devel
Requires:       cmake(KF5Wallet)
Requires:       cmake(KF5WidgetsAddons)
Requires:       cmake(Qt5Gui)

%description devel
KSaneCore is a Qt-based interface for SANE library to control scanner hardware.
This package contains the development files required to use KSaneCore in other
applications.

%package -n %{lname}%{_so}
Summary:        Qt interface for the SANE library for scanner hardware
Recommends:     %{name}-lang
Provides:       %{name} = %{version}

%description -n %{lname}%{_so}
KSaneCore is a Qt-based interface for SANE library to control scanner hardware.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DBUILD_TESTING=ON
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --with-man --all-name

%ldconfig_scriptlets -n %{lname}%{_so}

%files -n %{lname}%{_so}
%license LICENSES/*
%{_kf5_libdir}/%{lname}.so.*

%files devel
%{_kf5_cmakedir}/KSaneCore/
%{_includedir}/KSaneCore/
%{_kf5_libdir}/%{lname}.so

%files lang -f %{name}.lang

%changelog
* Sun Aug 18 2024 Javier Llorente <javier@opensuse.org>
- Add fix-scanner-search-crash.patch (kde#444987)
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 23.08.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.5/
- No code change since 23.08.4
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Add explicit moc includes to sources for moc-covered headers
  * Crop the image after a scan finished (kde#457097)
  * Also call renewImage() for 8-bit Gray images (kde#469683)
  * Have export macros header include version header (Qt6-only)
  * Support reading the gamma table
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Also call renewImage() for 8-bit Gray images (kde#469683)
  * Crop the image after a scan finished (kde#457097)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Sun Jul 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Fri May 27 2022 Luca Beltrame <lbeltrame@kde.org>
- Initial package
